# Changelog

## [0.1.0a10](https://github.com/OpenVoiceOS/ovos-backend-client/tree/0.1.0a10) (2023-09-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a9...0.1.0a10)

**Fixed bugs:**

- fix dataset upload [\#48](https://github.com/OpenVoiceOS/ovos-backend-client/pull/48) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a9](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a9) (2023-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a8...V0.1.0a9)

**Fixed bugs:**

- fix DeviceIdentity attribute access [\#49](https://github.com/OpenVoiceOS/ovos-backend-client/pull/49) ([emphasize](https://github.com/emphasize))

## [V0.1.0a8](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a8) (2023-08-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a7...V0.1.0a8)

## [V0.1.0a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a7) (2023-08-18)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a6...V0.1.0a7)

**Fixed bugs:**

- fix stt/ww dataset endpoints mixup [\#46](https://github.com/OpenVoiceOS/ovos-backend-client/pull/46) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a6) (2023-06-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a5...V0.1.0a6)

**Merged pull requests:**

- Import more xdg functions from ovos\_config rather than ovos\_utils [\#44](https://github.com/OpenVoiceOS/ovos-backend-client/pull/44) ([PureTryOut](https://github.com/PureTryOut))

## [V0.1.0a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a5) (2023-06-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a4...V0.1.0a5)

**Merged pull requests:**

- Import xdg functions from ovos\_config rather than ovos\_utils [\#43](https://github.com/OpenVoiceOS/ovos-backend-client/pull/43) ([PureTryOut](https://github.com/PureTryOut))

## [V0.1.0a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a4) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a3...V0.1.0a4)

**Implemented enhancements:**

- feat/admin\_update\_backend\_config [\#42](https://github.com/OpenVoiceOS/ovos-backend-client/pull/42) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a3) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.1.0a2...V0.1.0a3)

**Fixed bugs:**

- hotfix/rebase mess up in \#30 [\#41](https://github.com/OpenVoiceOS/ovos-backend-client/pull/41) ([JarbasAl](https://github.com/JarbasAl))

## [V0.1.0a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.1.0a2) (2023-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a9...V0.1.0a2)

**Implemented enhancements:**

- feat/DatabaseApi [\#30](https://github.com/OpenVoiceOS/ovos-backend-client/pull/30) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a9](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a9) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a8...V0.0.7a9)

**Breaking changes:**

- deprecate dead backends [\#39](https://github.com/OpenVoiceOS/ovos-backend-client/pull/39) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a8](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a8) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a7...V0.0.7a8)

**Merged pull requests:**

- Updated dependencies and automation [\#34](https://github.com/OpenVoiceOS/ovos-backend-client/pull/34) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.7a7](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a7) (2023-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a6...V0.0.7a7)

**Implemented enhancements:**

- add cache + fix geolocation [\#40](https://github.com/OpenVoiceOS/ovos-backend-client/pull/40) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a6](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a6) (2023-05-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a5...V0.0.7a6)

**Merged pull requests:**

- add package data [\#38](https://github.com/OpenVoiceOS/ovos-backend-client/pull/38) ([emphasize](https://github.com/emphasize))

## [V0.0.7a5](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a5) (2023-04-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a4...V0.0.7a5)

**Fixed bugs:**

- Personal-backend: Workaround deadlock [\#37](https://github.com/OpenVoiceOS/ovos-backend-client/pull/37) ([forslund](https://github.com/forslund))

**Closed issues:**

- Double acquire of combo-lock [\#36](https://github.com/OpenVoiceOS/ovos-backend-client/issues/36)

## [V0.0.7a4](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a4) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a3...V0.0.7a4)

**Implemented enhancements:**

- fix offline geolocate [\#33](https://github.com/OpenVoiceOS/ovos-backend-client/pull/33) ([emphasize](https://github.com/emphasize))

**Closed issues:**

- 'what is the weather in baltimore' returns an error \#30 [\#31](https://github.com/OpenVoiceOS/ovos-backend-client/issues/31)

## [V0.0.7a3](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a3) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a2...V0.0.7a3)

**Merged pull requests:**

- fix AudioFile offline import [\#35](https://github.com/OpenVoiceOS/ovos-backend-client/pull/35) ([emphasize](https://github.com/emphasize))

## [V0.0.7a2](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a2) (2023-02-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.7a1...V0.0.7a2)

**Fixed bugs:**

- fix/pairing\_checks\_for\_offline [\#29](https://github.com/OpenVoiceOS/ovos-backend-client/pull/29) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V0.0.7a1) (2023-02-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V0.0.6...V0.0.7a1)

**Implemented enhancements:**

- Add reverse geo api [\#27](https://github.com/OpenVoiceOS/ovos-backend-client/pull/27) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
